@@ -1,6 +1,7 @@
 use glob::{GlobError, PatternError};
 use std::fmt::{Display, Formatter, Result};
 use std::io::Error as IoError;
+use std::path::PathBuf;
 use toml::de::Error as TomlError;
 
 #[derive(Debug)]
@@ -8,8 +9,10 @@ pub enum Error {
     InvalidArgs,
     ManifestNotFound,
     RustcNotFound,
-    Io(IoError),
     GlobPatternError(&'static str),
+    Glob(GlobError),
+    Io(PathBuf, IoError),
+    Toml(PathBuf, TomlError),
 }
 
 impl Display for Error {
@@ -18,8 +21,10 @@ impl Display for Error {
             Self::InvalidArgs => "Invalid args.",
             Self::ManifestNotFound => "Didn't find Cargo.toml.",
             Self::RustcNotFound => "Didn't find rustc.",
-            Self::Io(error) => return error.fmt(f),
             Self::GlobPatternError(error) => error,
+            Self::Glob(error) => return error.fmt(f),
+            Self::Io(path, error) => return write!(f, "{}: {}", path.display(), error),
+            Self::Toml(file, error) => return write!(f, "{}: {}", file.display(), error),
         };
         write!(f, "{}", msg)
     }
@@ -27,18 +32,6 @@ impl Display for Error {
 
 impl std::error::Error for Error {}
 
-impl From<IoError> for Error {
-    fn from(error: IoError) -> Self {
-        Self::Io(error)
-    }
-}
-
-impl From<TomlError> for Error {
-    fn from(_error: TomlError) -> Self {
-        Self::ManifestNotFound
-    }
-}
-
 impl From<PatternError> for Error {
     fn from(error: PatternError) -> Self {
         Self::GlobPatternError(error.msg)
@@ -47,6 +40,6 @@ impl From<PatternError> for Error {
 
 impl From<GlobError> for Error {
     fn from(error: GlobError) -> Self {
-        Self::Io(error.into_error())
+        Self::Glob(error)
     }
 }
