@@ -10,8 +10,8 @@ pub struct Manifest {
 
 impl Manifest {
     pub fn parse_from_toml(path: &Path) -> Result<Self, Error> {
-        let contents = std::fs::read_to_string(path)?;
-        Ok(toml::from_str(&contents)?)
+        let contents = std::fs::read_to_string(path).map_err(|e| Error::Io(path.to_owned(), e))?;
+        toml::from_str(&contents).map_err(|e| Error::Toml(path.to_owned(), e))
     }
 }
 
